@@ -155,7 +155,7 @@ pub struct UseAsciiStringPattern<'a> {
 /// This can also be used for the `class` pattern.
 #[ffi_type(opaque)]
 #[repr(C)]
-pub struct Context {
+pub struct SomeContext {
     pub(crate) some_field: u32,
 }
 
